@@ -1,12 +1,12 @@
 ;;; notmuch-indicator.el --- Display mode line indicator with notmuch-count(1) output -*- lexical-binding: t -*-
 
-;; Copyright (C) 2022  Free Software Foundation, Inc.
+;; Copyright (C) 2022-2023  Free Software Foundation, Inc.
 
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; Maintainer: notmuch-indicator Development <~protesilaos/notmuch-indicator@lists.sr.ht>
 ;; URL: https://git.sr.ht/~protesilaos/notmuch-indicator
 ;; Mailing-List: https://lists.sr.ht/~protesilaos/notmuch-indicator
-;; Version: 0.2.2
+;; Version: 1.0.0
 ;; Package-Requires: ((emacs "27.1"))
 ;; Keywords: convenience, mail
 
@@ -39,7 +39,7 @@
 ;; purely cosmetic, though it helps characterise the resulting counter.
 ;;
 ;; The value of `notmuch-indicator-args' is a list of plists (property
-;; lists).  Each plist consists of one mandarory property and two
+;; lists).  Each plist consists of one mandatory property and two
 ;; optional ones:
 ;;
 ;; 1. The `:terms', which is required, is a string that holds the
@@ -178,11 +178,12 @@ option `notmuch-indicator-refresh-count'."
     (define-key map [mode-line mouse-1]
                 (lambda () (interactive) (notmuch-search terms)))
     (propertize
-     (format "%s%s "
+     (format "%s%s"
              (if (and face label)
                  (propertize label 'face face)
                (or label ""))
              count)
+     'mouse-face 'highlight
      'help-echo (format "mouse-1: Open notmuch search for `%s'" terms)
      'local-map map)))
 
@@ -202,7 +203,7 @@ option `notmuch-indicator-refresh-count'."
   "Parse `notmuch-indicator-args' and format them as single string."
   (mapconcat
    #'notmuch-indicator--format-output
-   notmuch-indicator-args ""))
+   notmuch-indicator-args " "))
 
 (defvar notmuch-indicator-string ""
   "String showing the `notmuch-indicator' state.
@@ -228,10 +229,11 @@ It is appended to the `global-mode-string'.")
 
 (defun notmuch-indicator--running-p ()
   "Return non-nil if `notmuch-indicator--indicator' is running."
-  (delq nil
-        (mapcar (lambda (timer)
-                  (eq (timer--function timer) 'notmuch-indicator--indicator))
-                timer-list)))
+  (when (executable-find "notmuch")
+    (delq nil
+          (mapcar (lambda (timer)
+                    (eq (timer--function timer) 'notmuch-indicator--indicator))
+                  timer-list))))
 
 (defun notmuch-indicator--run ()
   "Run the timer with a delay, starting it if necessary.
